function plat_av(obs::Vector{uwreal}, plat::Vector{Int64})
    uwerr.(obs)
    w = 1 ./ err.(obs)[plat[1]:plat[2]].^2
    av = sum(w .* obs[plat[1]:plat[2]]) / sum(w)
    return av 
end

function meff(obs::Vector{uwreal}, plat::Vector{Int64})
    dim = length(obs)
    aux = log.(obs[1:dim-1] ./ obs[2:dim])
    mass = plat_av(aux, plat)
    uwerr(mass)
    return mass
end

function apply_rw(cdata::CData, W::Array{Float64})
    W1 = W[1, :]
    W2 = W[2, :]
    cdata_r = copy(cdata)

    cdata_r.re_data = cdata.re_data .* W1 .* W2 / mean(W1 .* W2)
    cdata_r.im_data = cdata.im_data .* W1 .* W2 / mean(W1 .* W2)
    return cdata_r
end

function apply_rw(data::Array{Float64}, W::Array{Float64})
    W1 = W[1, :]
    W2 = W[2, :]

    data_r = data .* W1 .* W2 / mean(W1 .* W2)
    return data_r
end

function corr_obs(cdata::CData; real::Bool=true, rw::Union{Array{Float64}, Nothing}=nothing)

    real ? data = cdata.re_data : data = cdata.im_data
    isnothing(rw) ? data_r = data : data_r = apply_rw(data, rw)

    nt = size(data)[2]
    obs = Vector{uwreal}(undef, nt)
    [obs[x0] = uwreal(data_r[:, x0], cdata.id) for x0 = 1:nt]
    return Corr(obs, cdata)
end

#function corr_obs for R != 1
#TODO: vcfg with gaps
function corr_obs(cdata::Array{CData, 1}; real::Bool=true, rw::Union{Array{Array{Float64, 2}, 1}, Nothing}=nothing)
    nr = length(cdata)
    id = getfield.(cdata, Symbol("id"))
    vcfg = getfield.(cdata, Symbol("vcfg"))
    replica = Int64.(maximum.(vcfg))
    
    if !all(id .== id[1])
        println("IDs are not equal")
        return nothing
    end

    real ? data = getfield.(cdata, Symbol("re_data")) : data = getfield.(cdata, Symbol("im_data"))
    isnothing(rw) ? data_r = data : data_r = apply_rw.(data, rw)
    

    tmp = data_r[1]
    [tmp = cat(tmp, data_r[k], dims=1) for k = 2:nr]

    nt = size(data[1])[2]
    obs = Vector{uwreal}(undef, nt)

    [obs[x0] = uwreal(tmp[:, x0], id[1], replica) for x0 = 1:nt]

    return Corr(obs, cdata)
end    